@@ -2,5 +2,5 @@ from .convert import ConvertFractions
 from .operation import OperationFractions
 
 operation = OperationFractions()
-test = operation.division("3/2", 0)
+test = operation.root("-1/16", 4)
 print(test)
